@@ -1,21 +1,21 @@
 //! Utilities for writing formatted files
 
-use crate::args::*;
-use crate::fs;
-use crate::logging::*;
-use log::Level::Error;
-use std::path;
+use crate::args::Args;
+use crate::logging::{record_file_log, Log};
+use log::Level::{Error, Info};
+use std::fs;
+use std::path::Path;
 
 /// Write a formatted file to disk
-fn write_file(file: &str, text: &str) {
-    let filepath = path::Path::new(&file).canonicalize().unwrap();
+fn write_file(file: &Path, text: &str) {
+    let filepath = file.canonicalize().unwrap();
     fs::write(filepath, text).expect("Could not write the file");
 }
 
 /// Handle the newly formatted file
 pub fn process_output(
     args: &Args,
-    file: &str,
+    file: &Path,
     text: &str,
     new_text: &str,
     logs: &mut Vec<Log>,
@@ -27,6 +27,10 @@ pub fn process_output(
         return 1;
     } else if text != new_text {
         write_file(file, new_text);
+        if args.fail_on_change {
+            record_file_log(logs, Info, file, "Fixed incorrect formatting.");
+            return 1;
+        }
     }
     0
 }
